@@ -39,6 +39,11 @@ def readConfig(args):
             args.exclude_files.extend(
                 [f'{path}{line.strip()}'
                  for line in cfg[key].split('\n') if line != ''])
+        # files überschreiben das directory. Wenn dieses auch gescannt werden soll, muss es auch eingefügt werden.
+        if key == "parse_files":
+            args.files = [f'{path}{line.strip()}'
+                          for line in cfg[key].split('\n') if line != '']
+
     return args
 
 
@@ -63,6 +68,8 @@ def main() -> None:
                         default=[], help="file extensions to parse.")
     parser.add_argument("--print-token-tree", "-ptt", nargs='?', required=False,
                         const=True, default=False, help="print AST plus corresponding Tokens")
+    parser.add_argument("--output-style", "-out", choices=['stdErr', 'json'], required=False,
+                        default='stdErr', help="file extensions to parse.")
 
     args = parser.parse_args()
 
@@ -78,10 +85,11 @@ def main() -> None:
     if args.force_cpp:
         clang_args.extend(['-x', 'c++'])
 
+    FILE_EXTENSIONS: List[str] = []
     if args.extensions != []:
         FILE_EXTENSIONS = args.extensions
     else:
-        FILE_EXTENSIONS: List[str] = ["c", "h", "cpp", "hpp"]
+        FILE_EXTENSIONS = ["c", "h", "cpp", "hpp"]
 
     exfiles = set()
     for ex_file in args.exclude_files:
@@ -91,7 +99,7 @@ def main() -> None:
         else:
             exfiles.add(ex_file)
 
-    analyze_files = []
+    analyze_files: List[str] = []
     for in_file in args.files:
         if os.path.isdir(in_file):
             for ext in FILE_EXTENSIONS:
@@ -114,7 +122,10 @@ def main() -> None:
     for in_file in analyze_files:
         analyzer.analyze(in_file, printState)
 
-    out.printError()
+    if args.output_style == 'stdErr':
+        out.printError()
+    if args.output_style == "json":
+        out.printJson()
 
 
 if __name__ == "__main__":
